# About the structure: tutorials, how-to guides, technical reference and explanations

Our documentation follows the ["Diataxis documentation framework"](https://diataxis.fr/) proposed by [Daniel Procida](https://vurt.org/). This framework divide the documentation universe in four parts that represent different purposes or functions. They are: *Tutorials*, *How-to guides*, *Technical Reference* and *Explanations*.

### Brief Summary:

Table 1. Diataxis documentation framework (extracted from [link](https://docs.divio.com/documentation-system/introduction/))

|               | [Tutorials](https://diataxis.fr/tutorials/) | [How-to Guides](https://diataxis.fr/how-to-guides/)   | [Reference](https://diataxis.fr/reference/)   | [Explanation](https://diataxis.fr/)   |
|---------------|---------------------------------------------|-------------------------------------------------------|-----------------------------------------------|---------------------------------------|
| *what they do*| introduce, educate, lead                    | guide                                                 | state, describe, inform                       | explain, clarify, discuss             |
| *answers the question*|*Can you teach me to...?*            | *How do I...?*                                        | "What is...?"                                 | "Why...?"                             |
| *oriented to* | learning                                    | a goal                                                | information                                   | understanding                         |
| *purpose*     | to provide a learning experience            | to help achieve a particular goal                     | to describe the machinery                     | to illuminate a topic                 |
| *form*        | a lesson                                    | a series of steps                                     | dry description                               | discursive explanation                |
| *analogy*     | teaching a small child how to cook          | a recipe in a cookery book                            | a reference encyclopedia article              | an article on culinary social history |
